# Error Codes and Descriptions

Error codes are broken into 4 types of errors:

* Not Found - Requested items are not found
* Invalid Parameters - Method signatures do not match required inputs
* Validation Errors - Errors occured during factor graph operations for Updates
* Internal Processing Errors - Something really bad happened

TO DO:  Update with actual error codes, derived from interfaces.md and validation.md as they are created.